@@ -13,6 +13,7 @@ use List::Util qw(max min sum);
 use List::MoreUtils qw(uniq);
 use MIME::QuotedPrint ();
 use Time::Local ();
+use Time::HiRes;
 use utf8;
 
 our $default_transport = "http_cpantesters";
@@ -27,7 +28,7 @@ CPAN::Testers::ParseReport - parse reports to www.cpantesters.org from various s
 
 =cut
 
-use version; our $VERSION = qv('0.3.0');
+use version; our $VERSION = qv('0.4.0');
 
 =head1 SYNOPSIS
 
@@ -497,6 +498,7 @@ sub parse_report {
     my $expect_toolchain = 0;
     my $expecting_toolchain_soon = 0;
     my $expect_module_versions_report = 0;
+    my $expect_characteristics_libperl = 0;
     my $fallback_p5 = "";
 
     my $in_summary = 0;
@@ -504,6 +506,7 @@ sub parse_report {
     my $in_prg_output = 0;
     my $in_env_context = 0;
     my $in_test_summary = 0;
+    my $in_characteristics = 0;
 
     my $current_headline;
     my @previous_line = ""; # so we can neutralize line breaks
@@ -659,10 +662,38 @@ sub parse_report {
                 $in_summary_seen_platform=1;
             } elsif (/^\s*$/ || m|</pre>|) {
                 # if not html, we have reached the end now
-                if ($in_summary_seen_platform) {
-                    # some perls have an empty line after the summary line
+                if ($in_characteristics) {
                     $in_summary = 0;
+                } elsif ($in_summary_seen_platform) {
+                    # some perls have an empty line after the summary line
+                    $expect_characteristics_libperl = 1;
                 }
+            } elsif ($in_characteristics) {
+                if (my($date) = /Compiled at (.+)/) {
+                    $date =~ s/\s+\z//;
+                    # find: Apr 10 2013 16:59:47
+                    # want: 2016-07-05T11:03:04
+                    my($dt);
+                DATEFMT: for my $pat ("%b %d %Y %T") { # Sep 28 2008 12:23:12
+                        $dt = eval {
+                            my $p = DateTime::Format::Strptime->new
+                                (
+                                 locale => "en",
+                                 time_zone => "UTC",
+                                 pattern => $pat,
+                                );
+                            $p->parse_datetime($date)
+                        };
+                        last DATEFMT if $dt;
+                    }
+                    unless ($dt) {
+                        warn "Could not parse date[$date], setting to epoch 0";
+                        $dt = DateTime->from_epoch( epoch => 0 );
+                    }
+                    $extract{"meta:perl_compiled_at"} = $dt->datetime;
+                }
+            } elsif ($expect_characteristics_libperl && /Characteristics of this/) {
+                $in_characteristics = 1;
             } else {
                 my(%kv) = m!\G,?\s*([^=]+)= # left hand side and equal sign
                             (
@@ -1021,7 +1052,7 @@ one should look closer. Displays the N top candidates, where N
 defaults to 3 and can be set with the C<$Opt{solvetop}> variable.
 Regressions results with an R^2 of 1.00 are displayed in any case.
 
-The function is called when the option C<-solve> is give on the
+The function is called when the option C<-solve> is given on the
 commandline. Several extra config variables are calculated, see source
 code for details.
 
@@ -1029,19 +1060,28 @@ code for details.
 {
     my %never_solve_on = map {($_ => 1)}
         (
-         "conf:ccflags",
-         "conf:config_args",
-         "conf:cppflags",
-         "conf:lddlflags",
-         "conf:uname",
-         "env:PATH",
-         "env:PERL5LIB",
-         "env:PERL5OPT",
+         'conf:ccflags',
+         'conf:config_args',
+         'conf:cppflags',
+         'conf:lddlflags',
+         'conf:uname',
+         'conf:osvers',
          'env:$^X',
+         'env:PATH',
+         'env:PERL',
+         'env:PERL5LIB',
+         'env:PERL5OPT',
          'env:PERL5_CPANPLUS_IS_RUNNING',
          'env:PERL5_CPAN_IS_RUNNING',
          'env:PERL5_CPAN_IS_RUNNING_IN_RECURSION',
+         'env:PERL5_YACSMOKE_BASE',
+         'env:PERLBREW_MANPATH',
+         'env:PERLBREW_PATH',
+         'env:PERLBREW_PERL',
+         'env:PERL_CPAN_REPORTER_CONFIG',
+         'env:PERL_CPAN_REPORTER_DIR',
          'meta:ok',
+         'meta:perl_compiled_at',
         );
     my %normalize_numeric =
         (
@@ -1206,7 +1246,11 @@ sub solve {
             }
             push @{$regdata{data}}, \%obs;
         }
+        my $start = Time::HiRes::time;
         _run_regression ($variable, \%regdata, \@regression, \%Opt);
+        my $end = Time::HiRes::time;
+        warn sprintf "regressiontimings[%s]start[%s]end[%s]diff[%s]\n",
+            $variable, $start, $end, $end-$start unless $Opt{quiet};
     }
     my $top = min ($Opt{solvetop} || 3, scalar @regression);
     my $max_rsq = sum map {1==$_->rsq ? 1 : 0} @regression;
@@ -1327,7 +1371,7 @@ Thanks to RJBS for module-starter.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008,2009,2010,2011,2012,2013 Andreas König.
+Copyright 2008,2009,2010,2011,2012,2013,2014,2015,2016 Andreas König.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
